package org.wakeland.pedro;

import javax.microedition.lcdui.Canvas;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Font;
import javax.microedition.lcdui.Graphics;

/**
 * 
 * J2ME class for retrieving pressed game keys (UP, DOWN, LEFT, RIGHT) to control an NXT brick.
 * 
 * @author Peter (Pedro) Nosal, pedron4@gmail.com
 * @version 1.0
 *
 */
public class Joystick extends Canvas implements CommandListener {

	/**
	 * Instance of main class - MIDlet.
	 */
	private MobileImagineConnectorClient midlet;
	/**
	 * Instance of Font - for setting the font of the shown text.
	 */
	private Font font;
	/**
	 * Holds name of the pressed key.
	 */
	private String message = "[PRESS KEY]";
	/**
	 * Command for going back to MIDlet.
	 */
	private Command cmdBackToMidlet;

	/**
	 * Constructs new Joystick class.
	 * Creates command and sets font used in this class.
     * @param midlet	Main class - MIDlet.
	 */
	public Joystick(MobileImagineConnectorClient midlet){
		this.midlet = midlet;

		cmdBackToMidlet = new Command("Back", Command.BACK, 0);
		addCommand(cmdBackToMidlet);
		setCommandListener(this);

		font = Font.getFont(Font.FACE_PROPORTIONAL, Font.STYLE_PLAIN, Font.SIZE_MEDIUM);
	}

	/**
	 * From Canvas:
	 * Paints the name of the key pressed to the screen.
	 */
	public void paint(Graphics g){
		int width = getWidth();
		int height = getHeight();

		g.setColor(0, 0, 0);
		g.fillRect(0, 0, width - 1, height - 1);
		g.setColor(255, 255, 255);
		g.drawRect(0, 0, width - 1, height - 1);
		g.setFont(font);

		int x = width / 2;
		int y = height / 2;

		g.drawString(message, x, y, Graphics.BASELINE | Graphics.HCENTER);
	}

	/**
	 * From Canvas:
	 * Listens for pressed key.
	 */
	protected void keyPressed(int keyCode){
		int gameAction = getGameAction(keyCode);

		switch(gameAction){
		case UP:
			message = "[UP]";
			break;
		case DOWN:
			message = "[DOWN]";
			break;
		case LEFT:
			message = "[LEFT]";
			break;
		case RIGHT:
			message = "[RIGHT]";
			break;
		case FIRE:
			message = "[FIRE]";
			break;
		case GAME_A:
			message = "[LEFT_UP]";
			break;
		case GAME_B:
			message = "[RIGHT_UP]";
			break;
		case GAME_C:
			message = "[LEFT_DOWN]";
			break;
		case GAME_D:
			message = "[RIGHT_DOWN]";
			break;
		default:
			message = "";
			break;
		}
		sendKeyPressedToServer(message);
		repaint();
	}

	/**
	 * From CommandListener:
	 * Called by a system to indicate that a command has been invoked.
	 */
	public void commandAction(Command command, Displayable displayable) {
		if (command == cmdBackToMidlet){
			midlet.setMIDletDisplay(null, midlet.getFormMain());
		}
	}

	/**
	 * Sends the message to the MobileImagineConnectorServer
	 * with the name of the key pressed.
	 * @param key	Pressed key.
	 */
	private void sendKeyPressedToServer(String key){
		midlet.getObexClient();
		midlet.sendMessageToServer(key, ObexClient.MESSAGE_TYPE_BUTTON);
	}
}