package org.wakeland.pedro;

import java.util.TimerTask;

/**
 * A task object that can be scheduled for one-time or repeated execution 
 * by a Timer. Used in ObexClient object for sending GET requests
 * to MobileImagineConnectorServer.
 * 
 * <p>Sample code of OBEX server downloaded from
 * <a href="http://wiki.forum.nokia.com/index.php/Using_Bluetooth_OBEX_Client_in_Java_ME">Nokia wiki forum</a>.</p>
 * 
 * @author Peter (Pedro) Nosal, pedron4@gmail.com
 * @version 1.0
 *
 */
public class ObexClientTimerTask extends TimerTask {
    /**
     * Class used for calling GetMessageOnTimer() which create requests
     * to MobileImagineConnectorServer.
     */
	ObexClient parent;
 
    /**
     * Constructor, does nothing.
     * @param parent 	Parent class, used for calling GetMessageOnTimer() function in run(). 
     */
    public ObexClientTimerTask(ObexClient parent) {
        this.parent = parent;
    }
 
    /**
     * From TimerTask:
     * The action to be performed by this timer task.
     */
    public void run() {
        // calling function that create GET request to OBEX Server
        parent.GetMessageOnTimer();
    }
}